/*
Copyright © 2024 filifa

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"fmt"
	"log"
	"strconv"

	"github.com/spf13/cobra"
	"scm.dairydemon.net/filifa/mlblive/cmd/internal/statsapi"
)

func feed(cmd *cobra.Command, args []string) {
	pkStr := strconv.Itoa(gamePk)

	feedResp, err := statsapi.RequestFeed(pkStr)
	if err != nil {
		log.Fatal(err)
	}

	fmt.Println(string(feedResp))
}

// feedCmd represents the feed command
var feedCmd = &cobra.Command{
	Use:   "feed -g [gamePk]",
	Short: "Fetch the current state of a game",
	Long:  `Fetch the current state of a game.`,
	Args:  cobra.NoArgs,
	Run:   feed,
}

func init() {
	rootCmd.AddCommand(feedCmd)

	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// feedCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	feedCmd.Flags().IntVarP(&gamePk, "gamePk", "g", 0, "game PK")
	feedCmd.MarkFlagRequired("gamePk")
}
